"""SatNOGS Client module main function"""
from __future__ import absolute_import, division, print_function

import sys

import satnogsclient

if __name__ == '__main__':
    sys.exit(satnogsclient.main())
